;
; AutoIt Version: 3.0
; Language:       English
; Platform:       Windows XP / Citrix
; Original Author:         Nick Sindorf (Nick.Sindorf@bannerhealth.com)
; Modify Author: 		Robert Holland (Robert.Holland@bannerhealth.com)
; Original Date Created:   05-05-09
; Modify Date:   20091229

; Script Function:
;   Launch FirstNet from Citrix icon on desktop, Log on to Millennium and choose Show Board.
;   Loop the process for 24 Hours and Reboot the computer

; Modified Script Function:
;	Added Citrix variables to launch FirstNet from installed Citrix client in program files folder (Does not require icon on desktop).
;   Replaced messagebox with progress bar countdown for end-user notification.

;#NoTrayIcon
; Set the Millennium Username and Password to variables
$MilleUsername = "fnlobby"
$MillePassword = "fnlobby"

;Citrix Application Variables: Robert Holland
$ProgramFiles = @ProgramFilesDir
$PNAgent = "\Citrix\ICA Client\pnagent.exe"
$QLaunchSwitch = "/QLaunch"
$QLaunchArgument = "BH45D:AZBLD - Firstnet" ;Published Application Name. | BH45M: = Mock; BH45D: = Build; BH45P: = Production
$QuoteCharacter = Chr(34)
;$CitrixProcess = ProcessList("wfica32.exe")

;Progress bar time variables: Robert Holland
$InitialProgressBarTimeOut = 30 ;Seconds
$RestartProgressBarTimeOut = 15 ;Seconds
$InitialProgressBarStep = (100 / $InitialProgressBarTimeOut)
$SecondProgressBarStep = (100 / $RestartProgressBarTimeOut)
$CountDown1 = $InitialProgressBarTimeOut
$CountDown2 = $RestartProgressBarTimeOut

		While $Countdown1 > 0
		ProgressOn("", "FirstNet Starting in " & $InitialProgressBarTimeOut & " Seconds", "")
			For $i = 1 to 100 step $InitialProgressBarStep			
					ProgressSet( $i, "Banner Healthcare", " FirstNet Starting in " & $Countdown1 & " Seconds")
			sleep(1000)
			 $Countdown1 = $Countdown1 - 1
			Next
		 WEnd
		ProgressSet(100 , "Starting", "Complete")
		sleep(500)
		ProgressOff()

; Establish the counter and Set number of times to loop
; If loop_length = 48 the FN Monitor will run approximetly 24 hours before rebooting the computer. This is based on the program having to restart Citrix
; the half hour timeout. 48 half hours = 24 hours. : Robert Holland
$count = 0
$loop_length = 24 ;Citrix timeout has been changed to 60 minutes.

;Execute the loop "While" the $count is less than zero
While $count < $loop_length
	; Increase the count by one
	$count = $count + 1

;Launch Citrix from the program files folder. :Robert Holland
	Run($ProgramFiles & $PNAgent & " " & $QLaunchSwitch & " " & $QuoteCharacter & $QLaunchArgument & $QuoteCharacter)
	;MsgBox(8192, "Citrix path:", $ProgramFiles & $PNAgent & " " & $QLaunchSwitch & " " & $QuoteCharacter & $QLaunchArgument & $QuoteCharacter)

	If @error Then
		; A message box that lets the user know the script failed when launching the application and Exit Script.
		MsgBox(16, "AutoIt FN Monitor Script", "Failed when launching FN Monitor application.  Script Closed")
		Exit
	EndIf

    ; Wait for the Log On to become active
    WinWaitActive("HNAM Logon - \\Remote")

	; Log On with Username and Password set above
		Send( $MilleUsername & @TAB & $MillePassword & @TAB & @CR )

    ; Wait for the FN Application and Available Provider window to become active
		WinWaitActive("FirstNet Organizer for Lobbyview, Emergency", "", 1)

	;Wait 5 Seconds for Application to fully load
		Sleep(5000)

	;Press the ALT key on the keyboard and then choose List which is the second (L) on menubar and Show Board which is the second (S) in the dropdown menu.
		Send( "{ALT}" & "L" & "L"  )
		Sleep(2000)
		Send("{ENTER}")
		Send( "S" & "S"  )
		Sleep(1000)
		Send("{ENTER}")
	
;Close Citrix process every half hour.
;	Sleep(1800000)
;		for $i = 1 to $CitrixProcess[0][0]
;			ProcessClose ($CitrixProcess[$i][0])
;		next

	;Wait until the FN Monitor is closed
	WinWaitClose("FirstNet Organizer for Lobbyview, Emergency")
	
	; If the loop is going to continue then wait
		If $count < $loop_length Then
			While $Countdown2 > 0
			ProgressOn("", "FirstNet Restarting in " & $RestartProgressBarTimeOut & " Seconds", "")
				For $i = 1 to 100 step $SecondProgressBarStep			
					ProgressSet( $i, "Banner Healthcare", "FirstNet Restarting in " & $Countdown2 & " Seconds")
				sleep(1000)
				$Countdown2 = $Countdown2 - 1
				Next
			WEnd
			ProgressSet(100 , "Starting", "Complete")
			$CountDown2 = $RestartProgressBarTimeOut ;Reset the $CountDown2 variable so progress bar displays more than once.
			sleep(500)
			ProgressOff()
		EndIf

Wend  ; End While

;Force a reboot
Shutdown(6)

;Finished
Exit