;
; AutoIt Version: 3.0
; Language:       English
; Platform:       Windows XP / Citrix
; Original Author:         Nick Sindorf (Nick.Sindorf@bannerhealth.com)
; Modify Author: 		Robert Holland (Robert.Holland@bannerhealth.com)
; Original Date Created:   05-05-09
; Modify Date:   20091229

; Script Function:
;   Launch FirstNet from Citrix icon on desktop, Log on to Millennium and choose Show Board.
;   Loop the process for 24 Hours and Reboot the computer

; Modified Script Function:
;	Added Citrix variables to launch FirstNet from installed Citrix client in program files folder (Does not require icon on desktop).
;   Replaced messagebox with SplashScreen for end-user notification.

;#NoTrayIcon
; Set the Millennium Username and Password to variables
$MilleUsername = "fnlobby"
$MillePassword = "fnlobby"

;Citrix Application Variables: Robert Holland
$ProgramFiles = @ProgramFilesDir
$PNAgent = "\Citrix\ICA Client\pnagent.exe"
$QLaunchSwitch = "/QLaunch"
$QLaunchArgument = "BH45D:AZBLD - Firstnet" ;Published Application Name
$QuoteCharacter = Chr(34)

; Establish the counter and Set number of times to loop
; If loop_length = 48 the FN Monitor will run approximetly 24 hours before rebooting the computer. This is based on the program having to restart the Citrix
; every half hour. 48 half hours = 24 hours. : Robert Holland
$count = 0
$loop_length = 24

;Splashscreen for 30 seconds to alert the user that the program is running. : Robert Holland
SplashTextOn("Please Be Patient!", "Waiting 30 Seconds for Windows Startup to Complete.", 400, 100, -1, -1, 16, "", 20)
Sleep(30000)
SplashOff()

;Execute the loop "While" the counter is less than 
While $count < $loop_length
	; Increase the count by one
	$count = $count + 1

;Launch Citrix from the program files folder. :Robert Holland
	Run($ProgramFiles & $PNAgent & " " & $QLaunchSwitch & " " & $QuoteCharacter & $QLaunchArgument & $QuoteCharacter)
	;MsgBox(8192, "Citrix path:", $ProgramFiles & $PNAgent & " " & $QLaunchSwitch & " " & $QuoteCharacter & $QLaunchArgument & $QuoteCharacter)

	If @error Then
		; A message box that lets the user know the script failed when launching the application and Exit Script.
		MsgBox(16, "AutoIt FN Monitor Script", "Failed when launching FN Monitor application.  Script Closed")
		Exit
	EndIf

    ; Wait for the Log On to become active
    WinWaitActive("HNAM Logon - \\Remote")

    ; Log On with Username and Password set above
    Send( $MilleUsername & @TAB & $MillePassword & @TAB & @CR )

    ; Wait for the FN Application and Available Provider window to become active
	WinWaitActive("FirstNet Organizer for Lobbyview, Emergency", "", 1)

	;Wait 5 Seconds for Application to fully load
	Sleep(5000)

	;Press the ALT key on the keyboard and then choose List which is the second (L) on menubar and Show Board which is the second (S) in the dropdown menu.
	Send( "{ALT}" & "L" & "L"  )
	Sleep(2000)
	Send("{ENTER}")
	Send( "S" & "S"  )
	Sleep(1000)
	Send("{ENTER}")
	
	;Wait 2 seconds for window to open
	;Sleep(2000)
	
    ;Wait until the FN Monitor is closed
	WinWaitClose("FirstNet Organizer for Lobbyview, Emergency")
	
	; If the loop is going to continue Then wait
	If $count < $loop_length Then
			; Splashscreen for 15 seconds to let user know that the application is closed and waiting before FN Monitor restart. :Robert Holland
			SplashTextOn("FirstNet Monitor Script", "FirstNet Monitor Closed. Waiting 15 seconds before restart.", 400, 120, -1, -1, 16, "", 20)
			Sleep(15000)
			SplashOff()
	EndIf

Wend  ; End While

;Force a reboot
Shutdown(6)

;Finished
Exit