;
; AutoIt Version: 3.0
; Language:       English
; Platform:       Windows XP / Citrix
; Original Author:         Nick Sindorf (Nick.Sindorf@bannerhealth.com)
; Modify Author: 		Robert Holland (Robert.Holland@bannerhealth.com)
; Original Date Created:   05-05-09
; Modify Date Created:   20091229

; Script Function:
;   Launch FirstNet from Citrix icon on desktop, Log on to Millennium and choose Show Board.
;   Loop the process for 24 Hours and Reboot the computer

; Modified Script Function:
;	Launch FirstNet from installed Citrix client in program files folder (Does not require icon on desktop).

; Set the Millennium Username and Password to variables
$MilleUsername = "fnems"
$MillePassword = "fnems"

;Citrix Application Variables: Robert Holland
$ProgramFiles = @ProgramFilesDir
$PNAgent = "\Citrix\ICA Client\pnagent.exe"
$QLaunchSwitch = "/QLaunch"
$QLaunchArgument = "BH45P:EcodeFirstNet - Dev"
$QuoteCharacter = Chr(34)

; Establish the counter and Set number of times to loop
; If loop_length = 48 the FN Monitor will run approximetly 24 hours before rebooting the computer. This is based on the program having to restart the Citrix
; every half hour. 48 half hours = 24 hours. : Robert Holland
$count = 0
$loop_length = 48

;Splashscreen for 30 seconds to alert the user that the program is running. : Robert Holland
SplashTextOn("Please Be Patient!", "Waiting 30 Seconds for Windows Startup to Complete.", 400, 100, -1, -1, 16, "", 20)
Sleep(30000)
SplashOff()

; Execute the loop "While" the counter is less than 
While $count < $loop_length
	; Increase the count by one
	$count = $count + 1

;Launch Citrix from the program files folder. :Robert Holland
	Run($ProgramFiles & $PNAgent & " " & $QLaunchSwitch & " " & $QuoteCharacter & $QLaunchArgument & $QuoteCharacter)
	;MsgBox(8192, "QLaunch variables are:", $QLaunch & " " & $QuoteCharacter & $QLaunchArgument & $QuoteCharacter)

	If @error Then
		; A message box that lets the user know the script failed when launching the application and Exit Script.
		MsgBox(16, "AutoIt FN Monitor Script", "Failed when launching FN Monitor application.  Script Closed")
		Exit
	EndIf

    ; Wait for the Log On to become active
    WinWaitActive("HNAM Logon - \\Remote")

    ; Log On with Username and Password set above
    Send( $MilleUsername & @TAB & $MillePassword & @TAB & @CR )

    ; Wait for the FN Application and Available Provider window to become active
	WinWaitActive("Available Provider Check-In", "", 1)
	;Sleep 2 Seconds
	Sleep(20000)
	;Choose No and press Enter
	Send(@TAB & @CR)

	;Wait 5 Seconds for Application to fully load
	Sleep(5000)

	;Press the ALT key on the keyboard and then choose List (L) and Show Board (B)
	Send( "{ALT}" & "L" )
	Sleep(500)
	Send( "B" )
	
	;Wait 2 seconds for window to open
	Sleep(2000)
	
	;Set window so it is the top most application
    WinSetOnTop("All beds", "", 1)

    ;Wait until the FN Monitor is closed
	WinWaitClose("FirstNet Organizer")
	
	; If the loop is going to continue Then wait
	If $count < $loop_length Then
			; Splashscreen for 15 seconds to let user know that the application is closed and waiting before FN Monitor restart. :Robert Holland
			SplashTextOn("AutoIt FN Monitor Script", "FN Monitor Closed waiting 15 seconds before restart of FN Monitor", 400, 120, -1, -1, 16, "", 20)
			Sleep(15000)
			SplashOff()
	EndIf

Wend  ; End While

;Force a reboot
Shutdown(6)

;Finished
Exit